<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Schedule\Actions\AttendeeAction;
use Bixo\Schedule\Http\Requests\AttendeeActionRequest;
use Bixo\Schedule\Http\Resources\AttendeeResource;
use Bixo\Schedule\Models\Attendee;

/**
 * Admin web controller class.
 */
class AttendeeActionController extends BaseController
{

    /**
     * Action controller function for attendee.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AttendeeActionRequest $request, Attendee $attendee, $action)
    {
        try {
            $request = $request->all();
            $attendee = AttendeeAction::run($action, $attendee, $request);

            $data = new AttendeeResource($attendee);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('schedule::attendee.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('schedule/attendee/' . $attendee->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/attendee/' . $attendee->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
