<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Schedule\Actions\AttendeeExim;
use Bixo\Schedule\Http\Requests\AttendeeEximRequest;

/**
 * Admin web controller class.
 */
class AttendeeEximController extends BaseController
{
    /**
     * Action controller function for attendee.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AttendeeEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = AttendeeExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('schedule:attendee.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('schedule/attendee/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/attendee/' . $exim))
                ->redirect();
        }
    }
}
