<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Schedule\Http\Resources\ScheduleResource;
use Bixo\Schedule\Http\Resources\SchedulesCollection;
use Bixo\Schedule\Scopes\AttendeePublicScope;
use Bixo\Schedule\Models\Attendee;

class AttendeePublicController extends BaseController
{

    /**
     * Show attendee's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Attendee::pushScope(new RequestScope())
            ->pushScope(new AttendeePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $attendees = new AttendeesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('schedule::attendee.names'))
            ->view('schedule::public.attendee.index')
            ->data(compact('attendees', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show attendee.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Attendee::findBySlug($slug);
        $data = new AttendeeResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('schedule::attendee.name'))
            ->view('schedule::public.attendee.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
