<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Schedule\Actions\CalendarAction;
use Bixo\Schedule\Http\Requests\CalendarActionRequest;
use Bixo\Schedule\Http\Resources\CalendarResource;
use Bixo\Schedule\Models\Calendar;

/**
 * Admin web controller class.
 */
class CalendarActionController extends BaseController
{

    /**
     * Action controller function for calendar.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CalendarActionRequest $request, Calendar $calendar, $action)
    {
        try {
            $request = $request->all();
            $calendar = CalendarAction::run($action, $calendar, $request);

            $data = new CalendarResource($calendar);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('schedule::calendar.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('schedule/calendar/' . $calendar->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/calendar/' . $calendar->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
