<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Schedule\Actions\CalendarExim;
use Bixo\Schedule\Http\Requests\CalendarEximRequest;

/**
 * Admin web controller class.
 */
class CalendarEximController extends BaseController
{
    /**
     * Action controller function for calendar.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CalendarEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = CalendarExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('schedule:calendar.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('schedule/calendar/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/calendar/' . $exim))
                ->redirect();
        }
    }
}
