<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Schedule\Http\Resources\ScheduleResource;
use Bixo\Schedule\Http\Resources\SchedulesCollection;
use Bixo\Schedule\Scopes\CalendarPublicScope;
use Bixo\Schedule\Models\Calendar;

class CalendarPublicController extends BaseController
{

    /**
     * Show calendar's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Calendar::pushScope(new RequestScope())
            ->pushScope(new CalendarPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $calendars = new CalendarsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('schedule::calendar.names'))
            ->view('schedule::public.calendar.index')
            ->data(compact('calendars', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show calendar.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Calendar::findBySlug($slug);
        $data = new CalendarResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('schedule::calendar.name'))
            ->view('schedule::public.calendar.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
