<?php

namespace Bixo\Schedule\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Schedule\Actions\TaskAction;
use Bixo\Schedule\Http\Requests\TaskActionRequest;
use Bixo\Schedule\Http\Resources\TaskResource;
use Bixo\Schedule\Models\Task;

/**
 * Admin web controller class.
 */
class TaskActionController extends BaseController
{

    /**
     * Action controller function for task.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TaskActionRequest $request, Task $task, $action)
    {
        try {
            $request = $request->all();
            $task = TaskAction::run($action, $task, $request);

            $data = new TaskResource($task);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('schedule::task.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('schedule/task/' . $task->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/task/' . $task->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
