<?php

namespace Bixo\Schedule\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Schedule\Events\AttendeeAction as AttendeeActionEvent;
use Bixo\Schedule\Notifications\AttendeeAction as AttendeeActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AttendeeAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AttendeeActionEvent.
     *
     * @param   AttendeeActionEvent  $event
     * @return mixed
     */
    public function handle(AttendeeActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $attendee.
     *
     * @param   AttendeeActionEvent  $event
     * @return void
     */
    public function create(AttendeeActionEvent $event)
    {
        $client = $event->attendee->client;
        Notification::send($client, new AttendeeActionNotification($event));
    }

    /**
     * Handle the AttendeeActionEvent as a listener.
     *
     * @param   AttendeeActionEvent  $event
     * @return mixed
     */
    public function asListener(AttendeeActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AttendeeActionEvent  $event
     * @return bool
     */
    private function isAllowed(AttendeeActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
