<?php

namespace Bixo\Schedule\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Schedule\Events\CalendarAction as CalendarActionEvent;
use Bixo\Schedule\Notifications\CalendarAction as CalendarActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CalendarAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CalendarActionEvent.
     *
     * @param   CalendarActionEvent  $event
     * @return mixed
     */
    public function handle(CalendarActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $calendar.
     *
     * @param   CalendarActionEvent  $event
     * @return void
     */
    public function create(CalendarActionEvent $event)
    {
        $client = $event->calendar->client;
        Notification::send($client, new CalendarActionNotification($event));
    }

    /**
     * Handle the CalendarActionEvent as a listener.
     *
     * @param   CalendarActionEvent  $event
     * @return mixed
     */
    public function asListener(CalendarActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CalendarActionEvent  $event
     * @return bool
     */
    private function isAllowed(CalendarActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
