<?php

namespace Bixo\Schedule\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Schedule\Events\TaskAction as TaskActionEvent;
use Bixo\Schedule\Notifications\TaskAction as TaskActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TaskAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TaskActionEvent.
     *
     * @param   TaskActionEvent  $event
     * @return mixed
     */
    public function handle(TaskActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $task.
     *
     * @param   TaskActionEvent  $event
     * @return void
     */
    public function create(TaskActionEvent $event)
    {
        $client = $event->task->client;
        Notification::send($client, new TaskActionNotification($event));
    }

    /**
     * Handle the TaskActionEvent as a listener.
     *
     * @param   TaskActionEvent  $event
     * @return mixed
     */
    public function asListener(TaskActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TaskActionEvent  $event
     * @return bool
     */
    private function isAllowed(TaskActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
