<?php

namespace Bixo\Schedule\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Schedule\Events\TaskWorkflow as TaskWorkflowEvent;
use Bixo\Schedule\Notifications\TaskWorkflow as TaskWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TaskWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TaskWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $task is submitted.
     *
     * @param TaskWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TaskWorkflowEvent $event)
    {
        $client = $event->task->client;
        Notification::send($client, new TaskWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $task is published.
     *
     * @param TaskWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TaskWorkflowEvent $event)
    {
        $client = $event->task->client;
        Notification::send($client, new TaskWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $task is approved.
     *
     * @param TaskWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TaskWorkflowEvent $event)
    {
        $client = $event->task->client;
        Notification::send($client, new TaskWorkflowNotification($event));
    }

    /**
     * Handles the $task workflow event as a listener.
     *
     * @param TaskWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TaskWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
