<?php
namespace Bixo\Schedule\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Schedule\Events\AttendeeAction as AttendeeActionEvent;
use Bixo\Schedule\Models\Attendee;

class AttendeeAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $attendee;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AttendeeActionEvent $attendee
     */
    public function __construct(AttendeeActionEvent $attendee)
    {
        $this->action = $event->action;
        $this->attendee = $attendee;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Attendee Approved - ' . config('app.name'))
            ->view('schedule::attendee.email.action', ['data' => $this->attendee]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
