<?php
namespace Bixo\Schedule\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Schedule\Events\CalendarAction as CalendarActionEvent;
use Bixo\Schedule\Models\Calendar;

class CalendarAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $calendar;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CalendarActionEvent $calendar
     */
    public function __construct(CalendarActionEvent $calendar)
    {
        $this->action = $event->action;
        $this->calendar = $calendar;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Calendar Approved - ' . config('app.name'))
            ->view('schedule::calendar.email.action', ['data' => $this->calendar]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
