<?php
namespace Bixo\Schedule\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Schedule\Events\TaskAction as TaskActionEvent;
use Bixo\Schedule\Models\Task;

class TaskAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $task;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param TaskActionEvent $task
     */
    public function __construct(TaskActionEvent $task)
    {
        $this->action = $event->action;
        $this->task = $task;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Task Approved - ' . config('app.name'))
            ->view('schedule::task.email.action', ['data' => $this->task]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
