<?php

namespace Bixo\Schedule\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Schedule\Models\Attendee;

class AttendeePolicy
{

    use AttendeeAction;
    use AttendeeExim;
    use AttendeeReport;
    use AttendeeWorkflow;

    /**
     * Determine if the given user can view the attendee.
     *
     * @param Authenticatable $user
     * @param Attendee $attendee
     *
     * @return bool
     */
    public function view(Authenticatable $user, Attendee $attendee)
    {
        if ($authUser->canDo('schedule.attendee.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $attendee->is_owner;
    }

    /**
     * Determine if the given user can create a attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('schedule.attendee.create');
    }

    /**
     * Determine if the given user can update the given attendee.
     *
     * @param Authenticatable $user
     * @param Attendee $attendee
     *
     * @return bool
     */
    public function update(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.edit') && $user->isAdmin()) {
            return true;
        }

        return $attendee->is_owner;
    }

    /**
     * Determine if the given user can delete the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Attendee $attendee)
    {
        return $attendee->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
