<?php

namespace Bixo\Schedule\Policies;

use Bixo\Schedule\Models\Attendee;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait AttendeeWorkflow
{

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Attendee $attendee)
    {
        if ($user->canDo('schedule.attendee.reject')) {
            return true;
        }

        return false;
    }

}
