<?php

namespace Bixo\Schedule\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Schedule\Models\Calendar;

class CalendarPolicy
{

    use CalendarAction;
    use CalendarExim;
    use CalendarReport;
    use CalendarWorkflow;

    /**
     * Determine if the given user can view the calendar.
     *
     * @param Authenticatable $user
     * @param Calendar $calendar
     *
     * @return bool
     */
    public function view(Authenticatable $user, Calendar $calendar)
    {
        if ($authUser->canDo('schedule.calendar.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $calendar->is_owner;
    }

    /**
     * Determine if the given user can create a calendar.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('schedule.calendar.create');
    }

    /**
     * Determine if the given user can update the given calendar.
     *
     * @param Authenticatable $user
     * @param Calendar $calendar
     *
     * @return bool
     */
    public function update(Authenticatable $user, Calendar $calendar)
    {
        if ($user->canDo('schedule.calendar.edit') && $user->isAdmin()) {
            return true;
        }

        return $calendar->is_owner;
    }

    /**
     * Determine if the given user can delete the given calendar.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Calendar $calendar)
    {
        return $calendar->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
