<?php

namespace Bixo\Schedule\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Schedule\Models\Task;

class TaskPolicy
{

    use TaskAction;
    use TaskExim;
    use TaskReport;
    use TaskWorkflow;

    /**
     * Determine if the given user can view the task.
     *
     * @param Authenticatable $user
     * @param Task $task
     *
     * @return bool
     */
    public function view(Authenticatable $user, Task $task)
    {
        if ($authUser->canDo('schedule.task.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $task->is_owner;
    }

    /**
     * Determine if the given user can create a task.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('schedule.task.create');
    }

    /**
     * Determine if the given user can update the given task.
     *
     * @param Authenticatable $user
     * @param Task $task
     *
     * @return bool
     */
    public function update(Authenticatable $user, Task $task)
    {
        if ($user->canDo('schedule.task.edit') && $user->isAdmin()) {
            return true;
        }

        return $task->is_owner;
    }

    /**
     * Determine if the given user can delete the given task.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Task $task)
    {
        return $task->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
